@@ -13,7 +13,6 @@ sub new
   
   my %params = ();
   my %upload_data = ();
-  no warnings 'uninitialized';
   if( length($args{querystring}) )
   {
     foreach my $part ( split /&/, $args{querystring} )
@@ -155,17 +154,6 @@ sub unescape
   return $todecode;
 }# end unescape()
 
-
-#==============================================================================
-sub DESTROY
-{
-  my $s = shift;
-  
-  map { close($s->{uploads}->{$_}->{filehandle}) }
-    keys(%{$s->{uploads}});
-}# end DESTROY()
-
-
 1;# return true:
 
 =pod
